import { By } from '@angular/platform-browser';
import { SkyAppTestUtility } from '@skyux-sdk/testing';
import * as i0 from '@angular/core';
import { NgModule } from '@angular/core';
import { SkySplitViewModule } from '@skyux/split-view';
import { SkyThemeService } from '@skyux/theme';
import { SkyQueryableComponentHarness, SkyInputHarness, SkyComponentHarness } from '@skyux/core/testing';

/**
 * Provides information for and interaction with a SKY UX split view component.
 * By using the fixture API, a test insulates itself against updates to the internals
 * of a component, such as changing its DOM structure.
 * @internal
 */
class SkySplitViewFixture {
    #debugEl;
    /**
     * Returns information about the split view's drawer component.
     */
    get drawer() {
        const drawer = this.#getDrawer();
        return {
            ariaLabel: drawer.getAttribute('aria-label'),
            isVisible: !this.#drawerIsHidden(),
            width: drawer.style.width,
        };
    }
    /**
     * Returns information about the split view's workspace component.
     */
    get workspace() {
        const workspace = this.#getWorkspace();
        const backButton = this.#getBackToListButton();
        const workspaceIsHidden = this.#workspaceIsHidden();
        return {
            ariaLabel: workspace.getAttribute('aria-label'),
            backButtonIsVisible: !workspaceIsHidden && backButton !== undefined,
            backButtonText: SkyAppTestUtility.getText(backButton),
            isVisible: !workspaceIsHidden,
        };
    }
    #fixture;
    constructor(fixture, skyTestId) {
        this.#fixture = fixture;
        this.#debugEl = SkyAppTestUtility.getDebugElementByTestId(fixture, skyTestId, 'sky-split-view');
        // the component takes a while to initialize so we need to wait
        void this.#waitForComponent();
    }
    /**
     * Opens the drawer component when in responsive mode. This method clicks the back to list
     * button, if it is visible.
     */
    async openDrawer() {
        const backButton = this.#getBackToListButton();
        if (backButton !== undefined) {
            backButton.click();
            this.#fixture.detectChanges();
            await this.#fixture.whenStable();
        }
    }
    // #region helpers
    #getDrawer() {
        return this.#debugEl.query(By.css('.sky-split-view-drawer')).nativeElement;
    }
    #drawerIsHidden() {
        const drawer = this.#debugEl.query(By.css('.sky-split-view-drawer-flex-container')).nativeElement;
        return drawer.hasAttribute('hidden');
    }
    #getWorkspace() {
        return this.#debugEl.query(By.css('.sky-split-view-workspace'))
            .nativeElement;
    }
    #workspaceIsHidden() {
        const workspace = this.#debugEl.query(By.css('.sky-split-view-workspace-flex-container')).nativeElement;
        return workspace.hasAttribute('hidden');
    }
    #getBackToListButton() {
        return this.#debugEl.query(By.css('.sky-split-view-workspace-header-content > button'))?.nativeElement;
    }
    async #waitForComponent() {
        this.#fixture.detectChanges();
        await this.#fixture.whenStable();
        this.#fixture.detectChanges();
        await this.#fixture.whenStable();
    }
}

/**
 * @internal
 */
class SkySplitViewTestingModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewTestingModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewTestingModule, exports: [SkySplitViewModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewTestingModule, providers: [SkyThemeService], imports: [SkySplitViewModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewTestingModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [SkySplitViewModule],
                    providers: [SkyThemeService],
                }]
        }] });

/**
 * Harness to interact with the split view drawer component in tests.
 */
class SkySplitViewDrawerHarness extends SkyQueryableComponentHarness {
    /**
     * @internal
     */
    static { this.hostSelector = 'sky-split-view-drawer'; }
    #getDrawer = this.locatorFor('.sky-split-view-drawer');
    /**
     * The aria-label property of the split view drawer
     */
    async getAriaLabel() {
        return await (await this.#getDrawer()).getAttribute('aria-label');
    }
}

/**
 * Harness to interact with the split view workspace content component in tests.
 */
class SkySplitViewWorkspaceContentHarness extends SkyQueryableComponentHarness {
    /**
     * @internal
     */
    static { this.hostSelector = 'sky-split-view-workspace-content'; }
}

/**
 * Harness to interact with the split view workspace footer component in tests.
 */
class SkySplitViewWorkspaceFooterHarness extends SkyQueryableComponentHarness {
    /**
     * @internal
     */
    static { this.hostSelector = 'sky-split-view-workspace-footer'; }
}

/**
 * Harness to interact with the split view workspace header component in tests.
 * @internal
 */
class SkySplitViewWorkspaceHeaderHarness extends SkyInputHarness {
    /**
     * @internal
     */
    static { this.hostSelector = 'sky-split-view-workspace-header'; }
    #getButton = this.locatorFor('.sky-split-view-workspace-header-content button');
    /**
     * Gets the button element.
     * @internal
     */
    async getBackButton() {
        return await this.#getButton();
    }
}

/**
 * Harness to interact with the split view workspace component in tests.
 */
class SkySplitViewWorkspaceHarness extends SkyQueryableComponentHarness {
    /**
     * @internal
     */
    static { this.hostSelector = 'sky-split-view-workspace'; }
    #getContent = this.locatorForOptional(SkySplitViewWorkspaceContentHarness);
    #getFooter = this.locatorForOptional(SkySplitViewWorkspaceFooterHarness);
    #getHeader = this.locatorForOptional(SkySplitViewWorkspaceHeaderHarness);
    #getWorkspace = this.locatorFor('.sky-split-view-workspace');
    /**
     * The aria-label property of the split view workspace
     */
    async getAriaLabel() {
        return await (await this.#getWorkspace()).getAttribute('aria-label');
    }
    /**
     * Gets the workspace content component.
     */
    async getContent() {
        const content = await this.#getContent();
        if (content === null) {
            throw Error('Could not find split view workspace content.');
        }
        return content;
    }
    /**
     * Gets the workspace footer component.
     */
    async getFooter() {
        const footer = await this.#getFooter();
        if (footer === null) {
            throw Error('Could not find split view workspace footer.');
        }
        return footer;
    }
    /**
     * Gets the workspace header component.
     * @internal
     */
    async getHeader() {
        const header = await this.#getHeader();
        if (header === null) {
            throw Error('Could not find split view workspace header.');
        }
        return header;
    }
}

/**
 * Harness for interacting with a split view component in tests.
 */
class SkySplitViewHarness extends SkyComponentHarness {
    /**
     * @internal
     */
    static { this.hostSelector = 'sky-split-view'; }
    #getSplitView = this.locatorFor('.sky-split-view');
    #getSplitViewDrawer = this.locatorForOptional(SkySplitViewDrawerHarness);
    #getSplitViewDrawerContainer = this.locatorFor('.sky-split-view-drawer-flex-container');
    #getSplitViewWorkspace = this.locatorForOptional(SkySplitViewWorkspaceHarness);
    #getSplitViewWorkspaceContainer = this.locatorFor('.sky-split-view-workspace-flex-container');
    /**
     * Gets a `HarnessPredicate` that can be used to search for a
     * `SkySplitViewHarness` that meets certain criteria.
     */
    static with(filters) {
        return SkySplitViewHarness.getDataSkyIdPredicate(filters);
    }
    /**
     * Gets the text for the button that appears in the workspace header in responsive mode.
     */
    async getBackButtonText() {
        return (await (await this.#getBackButton()).text()).trim();
    }
    /**
     * Gets the type of dock style on the split view.
     */
    async getDockType() {
        const dockClass = await (await this.#getSplitView()).hasClass('sky-split-view-dock-fill');
        return dockClass ? 'fill' : 'none';
    }
    /**
     * Gets a 'SkySplitViewDrawerHarness`.
     */
    async getDrawer() {
        const drawer = await this.#getSplitViewDrawer();
        if (!drawer) {
            throw Error('Could not find split view drawer.');
        }
        return drawer;
    }
    /**
     * Whether the drawer component is visible
     */
    async getDrawerIsVisible() {
        const drawerContainer = await this.#getSplitViewDrawerContainer();
        return (await drawerContainer.getAttribute('hidden')) === null;
    }
    /**
     * Gets a `SkySplitViewWorkspaceHarness`.
     */
    async getWorkspace() {
        const workspace = await this.#getSplitViewWorkspace();
        if (!workspace) {
            throw Error('Could not find split view workspace.');
        }
        return workspace;
    }
    /**
     * Whether the workspace component is visible.
     */
    async getWorkspaceIsVisible() {
        const workspaceContainer = await this.#getSplitViewWorkspaceContainer();
        return (await workspaceContainer.getAttribute('hidden')) === null;
    }
    /**
     * Opens the drawer component when in responsive mode.
     */
    async openDrawer() {
        const button = await this.#getBackButton();
        await button.click();
    }
    async #getBackButton() {
        const workspace = await this.getWorkspace();
        return await (await workspace.getHeader()).getBackButton();
    }
}

/**
 * Generated bundle index. Do not edit.
 */

export { SkySplitViewDrawerHarness, SkySplitViewFixture, SkySplitViewHarness, SkySplitViewTestingModule, SkySplitViewWorkspaceContentHarness, SkySplitViewWorkspaceFooterHarness, SkySplitViewWorkspaceHarness };
//# sourceMappingURL=skyux-split-view-testing.mjs.map
